Coconut
=======

Coconut (`coconut-lang.org`__) is a variant of Python_ that **adds on top of Python syntax** new features for simple, elegant, Pythonic **functional programming**.

Coconut is developed on GitHub_ and hosted on PyPI_. Installing Coconut is as easy as opening a command prompt and entering::

    pip install coconut

after which the entire world of Coconut will be at your disposal. To help you get started, check out these links for more information about Coconut:

- Tutorial_: If you're new to Coconut, a good place to start is Coconut's **tutorial**.
- Documentation_: If you're looking for info about a specific feature, check out Coconut's **documentation**.
- FAQ_: If you have questions about who Coconut is built for and whether or not you should use it, Coconut's frequently asked questions have you covered.
- `Create a New Issue <https://github.com/evhub/coconut/issues/new>`_: If you're having a problem with Coconut, creating a new issue detailing the problem will allow it to be addressed as soon as possible.
- Gitter_: For any questions, concerns, or comments about anything Coconut-related, ask around at Coconut's Gitter, a GitHub-integrated chat room for Coconut developers.
- Releases_: Want to know what's been added in recent Coconut versions? Check out the release log for all the new features and fixes.

__ Coconut_
.. _Coconut: http://coconut-lang.org/
.. _Python: https://www.python.org/
.. _PyPI: https://pypi.python.org/pypi/coconut
.. _Tutorial: http://coconut.readthedocs.io/en/master/HELP.html
.. _Documentation: http://coconut.readthedocs.io/en/master/DOCS.html
.. _FAQ: http://coconut.readthedocs.io/en/master/FAQ.html
.. _GitHub: https://github.com/evhub/coconut
.. _Gitter: https://gitter.im/evhub/coconut
.. _Releases: https://github.com/evhub/coconut/releases
